searchData={"items":[{"type":"module","title":"Stl","doc":"A fast and reliable Elixir library for decomposing time series data using STL (Seasonal and Trend decomposition using Loess). This package provides Elixir bindings to the STL C++ library `https://github.com/ankane/stl-cpp` using Fine to handle implementing the NIF.\n\n  It supports both Seasonal-trend and Multi Seasonal-trend decomposition using `decompose/2` and `decompose/3` respectively, with the ability to smooth outliers with `robust` decomposition. See the docs for `decompose/2` and `decompose/3` for more details.\n\n  For a single seasonal trend, you can pass a list of values or a Date keyed map as the series.\n\n  ```\n  # Decompose a simple list with a weekly seasonal pattern\n  series = [5.0, 9.0, 2.0, 9.0, 0.0, 6.0, 3.0, 8.0, 5.0, 8.0,\n            7.0, 8.0, 8.0, 0.0, 2.0, 5.0, 0.0, 5.0, 6.0, 7.0,\n            3.0, 6.0, 1.0, 4.0, 4.0, 4.0, 3.0, 7.0, 5.0, 8.0]\n\n  result = Stl.decompose(series, 7)\n\n  # Access the components\n  seasonal = result.seasonal\n  trend = result.trend\n  remainder = result.remainder\n\n  # Calculate strength measures\n  seasonal_strength = Stl.seasonal_strength(result)\n  trend_strength = Stl.trend_strength(result)\n\n  IO.puts(\"Seasonal strength: #{seasonal_strength}\")\n  # Seasonal strength: 0.28411169658385693\n  IO.puts(\"Trend strength: #{trend_strength}\")\n  # Trend strength: 0.16384239106781462\n  ```\n\n  For multi seasonal trends, the second param should be an integer list of periods.\n\n  ```\n  Stl.decompose(series, [7, 30])\n  ```","ref":"Stl.html"},{"type":"function","title":"Stl.decompose/3","doc":"Decompose a time series using STL (Seasonal and Trend decomposition using Loess).","ref":"Stl.html#decompose/3"},{"type":"function","title":"Parameters - Stl.decompose/3","doc":"* `series` - A list of numbers or a map with keys (e.g., dates) and values.\n* `:period` - REQUIRED: The period of the seasonal component (must be >= 2).\n* `opts` - Options for the decomposition:\n  * `:seasonal_length` - Length of the seasonal smoother.\n  * `:trend_length` - Length of the trend smoother.\n  * `:low_pass_length` - Length of the low-pass filter.\n  * `:seasonal_degree` - Degree of locally-fitted polynomial in seasonal smoothing (0 or 1).\n  * `:trend_degree` - Degree of locally-fitted polynomial in trend smoothing (0 or 1).\n  * `:low_pass_degree` - Degree of locally-fitted polynomial in low-pass smoothing (0 or 1).\n  * `:seasonal_jump` - Skipping value for seasonal smoothing.\n  * `:trend_jump` - Skipping value for trend smoothing.\n  * `:low_pass_jump` - Skipping value for low-pass smoothing.\n  * `:inner_loops` - Number of loops for updating the seasonal and trend components.\n  * `:outer_loops` - Number of iterations of robust fitting.\n  * `:robust` - If robustness iterations are to be used (boolean).\n  * `:include_weights` - Whether to include robustness weights in the result (boolean).\n  * For MSTL (when period is a list):\n  * `:iterations` - Number of iterations for MSTL.\n  * `:lambda` - Lambda for Box-Cox transformation (between 0 and 1).\n  * `:seasonal_lengths` - Lengths of the seasonal smoothers.","ref":"Stl.html#decompose/3-parameters"},{"type":"function","title":"Examples - Stl.decompose/3","doc":"","ref":"Stl.html#decompose/3-examples"},{"type":"function","title":"Standard STL decomposition (single period): - Stl.decompose/3","doc":"# Decompose with weekly seasonality\n      result = Stl.decompose(series, 7)\n\n      # Access components\n      seasonal = result.seasonal\n      trend = result.trend\n      remainder = result.remainder\n\n      # With robustness\n      result = Stl.decompose(series, 7, robust: true)\n      weights = result.weights","ref":"Stl.html#decompose/3-standard-stl-decomposition-single-period"},{"type":"function","title":"MSTL decomposition (multiple periods): - Stl.decompose/3","doc":"# Decompose with both weekly and yearly seasonality\n      result = Stl.decompose(series, [7, 365])\n\n      # Access seasonal components\n      weekly_seasonal = Enum.at(result.seasonal, 0)\n      yearly_seasonal = Enum.at(result.seasonal, 1)\n\n      # With additional MSTL options\n      result = Stl.decompose(series, [7, 365],\n        iterations: 2,\n        lambda: 0.5,\n        seasonal_lengths: [11, 731]\n      )","ref":"Stl.html#decompose/3-mstl-decomposition-multiple-periods"},{"type":"type","title":"Stl.robust_stl/0","doc":"Result of a robust STL decomposition.","ref":"Stl.html#t:robust_stl/0"},{"type":"function","title":"Stl.seasonal_strength/1","doc":"Calculate the seasonal strength from a decomposition result.\n\nReturns a float value between 0 and 1 representing the seasonal strength to signify a detected seasonal trend.\n\nValues range from 0.0 to 1.0, where:\n- 0.0 means no strength\n- 1.0 means maximum strength","ref":"Stl.html#seasonal_strength/1"},{"type":"function","title":"Examples - Stl.seasonal_strength/1","doc":"iex> result = Stl.decompose([5.0, 9.0, 2.0, 9.0, 0.0, 6.0, 3.0], 2)\n    iex> Stl.seasonal_strength(result)\n    0.9422302715663797","ref":"Stl.html#seasonal_strength/1-examples"},{"type":"type","title":"Stl.t/0","doc":"Result of STL decomposition.","ref":"Stl.html#t:t/0"},{"type":"function","title":"Stl.trend_strength/1","doc":"Calculate the trend strength from a decomposition result.\n\nExpects a decomposition map containing `:trend` and `:remainder` components.\n\nReturns a float value between 0 and 1 representing the trend strength.","ref":"Stl.html#trend_strength/1"},{"type":"function","title":"Examples - Stl.trend_strength/1","doc":"iex> result = Stl.decompose([5.0, 9.0, 2.0, 9.0, 0.0, 6.0, 3.0], 2)\n    iex> Stl.trend_strength(result)\n    0.727898191447705","ref":"Stl.html#trend_strength/1-examples"},{"type":"module","title":"Stl.Params","doc":"","ref":"Stl.Params.html"},{"type":"type","title":"Stl.Params.t/0","doc":"","ref":"Stl.Params.html#t:t/0"},{"type":"module","title":"Stl.Utils","doc":"Utility functions for working with STL decompositions.","ref":"Stl.Utils.html"},{"type":"function","title":"Stl.Utils.iso8601/1","doc":"Formats date or datetime value to ISO8601 string.","ref":"Stl.Utils.html#iso8601/1"},{"type":"function","title":"Parameters - Stl.Utils.iso8601/1","doc":"* `value` - A Date or DateTime value.","ref":"Stl.Utils.html#iso8601/1-parameters"},{"type":"function","title":"Returns - Stl.Utils.iso8601/1","doc":"An ISO8601 formatted string.","ref":"Stl.Utils.html#iso8601/1-returns"},{"type":"function","title":"Stl.Utils.var/1","doc":"Calculate the variance of a list of numbers.","ref":"Stl.Utils.html#var/1"},{"type":"function","title":"Parameters - Stl.Utils.var/1","doc":"* `series` - A list of numbers.","ref":"Stl.Utils.html#var/1-parameters"},{"type":"function","title":"Returns - Stl.Utils.var/1","doc":"The variance of the series.","ref":"Stl.Utils.html#var/1-returns"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}